==> PIPython-2.3.0.3.tar.gz: PIPython-2.3.0.3/pipython/pidevice/gcs2/gcs2commands.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
"""Provide GCS functions to control a PI device."""
# Trailing newlines pylint: disable=C0305

from logging import warning
# Wildcard import pipython.gcscommands_helpers pylint: disable=W0401
# Unused import platform from wildcard import pylint: disable=W0614
from ..common.gcscommands_helpers import *
from ..common.gcsbasecommands import GCSBaseCommands

__signature__ = 0x4a6b18b1a5369daecd79ad2a66b6fa6b

GCSFUNCTIONS = {
    'E-816': [
        'qERR', 'qI2C', 'qIDN', 'StopAll', 'BDR', 'qBDR', 'AVG', 'qAVG', 'SCH', 'qSCH', 'qSAI', 'MAC_BEG', 'MAC_START',
        'MAC_NSTART', 'MAC_DEL', 'MAC_DEF', 'MAC_END', 'MAC_qDEF', 'MAC_qFREE', 'qMAC', 'IsRunningMacro', 'DEL', 'WPA',
        'RST', 'qHLP', 'DCO', 'qDCO', 'MOV', 'MVR', 'qMOV', 'SVA', 'SVR', 'qSVA', 'MVT', 'qMVT', 'qDIP', 'qPOS', 'qVOL',
        'qOVF', 'qONT', 'SVO', 'qSVO', 'SWT', 'qSWT', 'WTO', 'SPA', 'qSPA',
    ],
    'HEXAPOD': [
        'qIDN', 'AAP', 'qCST', 'qECO', 'qERR', 'FAA', 'FAM', 'FAS', 'DMOV', 'DRV', 'FIO', 'FSA', 'FSC', 'FSM', 'FSN',
        'GetPosStatus', 'GetScanResult', 'HasPosChanged', 'INI', 'IsMoving', 'IsRecordingMacro', 'IsScanning',
        'MAC_BEG', 'MAC_DEL', 'MAC_END', 'MAC_qERR', 'MAC_START', 'MOV', 'MWG', 'NAV', 'NLM', 'PLM', 'qCST', 'qDRR',
        'qFSN', 'qHLP', 'qMAC', 'qNAV', 'qNLM', 'qPLM', 'qPOS', 'qSAI', 'qSAI_ALL', 'qSCT', 'qSGA', 'qSPA', 'qSPI',
        'qSSL', 'qSST', 'qSVO', 'qTAV', 'qVEL', 'qVER', 'SCT', 'SGA', 'SPI', 'SSL', 'SST', 'STP', 'SVO', 'TAV', 'VEL',
        'VMO',
    ],
    'TRIPOD': [
        'qIDN', 'AAP', 'qCST', 'qECO', 'qERR', 'FAA', 'FAM', 'FAS', 'DMOV', 'DRV', 'FIO', 'FSA', 'FSC', 'FSM', 'FSN',
        'GetPosStatus', 'GetScanResult', 'HasPosChanged', 'INI', 'IsMoving', 'IsRecordingMacro', 'IsScanning',
        'MAC_BEG', 'MAC_DEL', 'MAC_END', 'MAC_qERR', 'MAC_START', 'MOV', 'MWG', 'NAV', 'NLM', 'PLM', 'qCST', 'qDRR',
        'qFSN', 'qHLP', 'qMAC', 'qNAV', 'qNLM', 'qPLM', 'qPOS', 'qSAI', 'qSAI_ALL', 'qSCT', 'qSGA', 'qSPA', 'qSPI',
        'qSSL', 'qSST', 'qSVO', 'qTAV', 'qVEL', 'qVER', 'SCT', 'SGA', 'SPI', 'SSL', 'SST', 'STP', 'SVO', 'TAV', 'VEL',
        'VMO',
    ],
    'C-702.00': [
        'IsMoving', 'HasPosChanged', 'IsControllerReady', 'IsRunningMacro', 'StopAll', 'SystemAbort', 'q*IDN', 'ACC',
        'qACC', 'CCL', 'qCCL', 'CLR', 'CLS', 'CST', 'qCST', 'qCSV', 'CTO', 'qCTO', 'DEL', 'DFF', 'qDFF', 'DFH', 'qDFH',
        'DIO', 'qDIO', 'DRC', 'qDRC', 'qDRR', 'DRT', 'qDRT', 'DSP', 'qDSP', 'qECO', 'qERR', 'GOH', 'qHDR', 'HID',
        'qHID', 'qHLP', 'HLT', 'IFC', 'qIFC', 'IFS', 'qIFS', 'INI', 'ITD', 'qLIM', 'MAC', 'qMAC', 'MNL', 'MOV', 'qMOV',
        'MPL', 'MSG', 'MVR', 'MVS', 'qMVS', 'NLM', 'qNLM', 'qONT', 'PLM', 'qPLM', 'POS', 'qPOS', 'RBT', 'REF', 'qREF',
        'RON', 'qRON', 'RST', 'RTR', 'qRTR', 'SAI', 'qSAI', 'SAV', 'SCA', 'qSCA', 'SMO', 'qSMO', 'SPA', 'qSPA', 'SSL',
        'qSSL', 'qSSN', 'SSP', 'SST', 'qSST', 'qSTA', 'STP', 'SVO', 'qSVO', 'qTAC', 'qTCV', 'qTIM', 'qTIO', 'qTMN',
        'qTMX', 'qTNR', 'TRO', 'qTRO', 'qTSP', 'qTVI', 'VEL', 'qVEL', 'qVER', 'VMO', 'qVST', 'WAA', 'WAI', 'WAV',
        'qWAV', 'WGO', 'qWGO', 'WPA', 'WSL', 'qWSL',
    ]
}


class GCS2Commands(GCSBaseCommands):
    """Provide functions for GCS commands and communicate with PI controller."""

    def __init__(self, msgs):
        """Wrapper for PI GCS DLL.
        @type msgs : pipython.pidevice.gcsmessages.GCSMessages
        """
        debug('create an instance of GCS2Commands(msgs=%s)', str(msgs))
        super(GCS2Commands, self).__init__(msgs)

    def __str__(self):
        return 'GCS2Commands(msgs=%s)' % str(self._msgs)

    #    @property
    #    def connectionid(self):
    #        """Get ID of current connection as integer."""
    #        return super(GCS2Commands, self).connectionid

    @property
    def devname(self):
        """Return device name from its IDN string."""
        if self._name is None:
            idn = self.qIDN().upper()
            if 'PI-E816' in idn:
                self._name = 'E-816'
            elif 'DIGITAL PIEZO CONTROLLER' in idn:
                self._name = 'E-710'
            else:
                self._name = idn.split(',')[1].strip()
            debug('GCS2Commands.devname: set to %r', self._name)
        return self._name

    @devname.setter
    def devname(self, devname):
        """Set device name as string, only for testing."""
        super(GCS2Commands, self.__class__).devname.fset(self, devname)
        warning('controller name is coerced to %r', self._name)

    @devname.deleter
    def devname(self):
        """Reset device name."""
        self._name = None
        super(GCS2Commands, self.__class__).devname.fdel(self)
        debug('GCS2Commands.devname: reset')

    @property
    def funcs(self):
        """Return list of supported GCS functions."""
        if self._funcs is None:
            if self.devname in GCSFUNCTIONS:
                self._funcs = GCSFUNCTIONS[self.devname]
            else:
                self._funcs = getsupportedfunctions(self.qHLP())
        return self._funcs

    @funcs.deleter
    def funcs(self):
        """Reset list of supported GCS functions."""
        debug('GCS2Commands.funcs: reset')
        super(GCS2Commands, self.__class__).funcs.fdel(self)

    def paramconv(self, paramdict):
        """Convert values in 'paramdict' to according type in qHPA answer.
        @paramdict: Dictionary of {item: {param: value}}.
        @return: Dictionary of {item: {param: value}}.
        """
        self.initparamconv()

        for item in paramdict:
            for param in paramdict[item]:
                if param in self._settings['paramconv']:
                    paramdict[item][param] = self._settings['paramconv'][param](paramdict[item][param])

        return paramdict

    def initparamconv(self):
        """Initialize paramconv .
        """
        if not self._settings['paramconv']:
            for line in self.qHPA().splitlines():
                if '=' not in line:
                    continue
                paramid = int(line.split('=')[0].strip(), base=16)
                convtype = line.split()[3].strip()
                if convtype.upper() == 'INT':
                    self._settings['paramconv'][paramid] = self._int
                elif convtype.upper() == 'FLOAT':
                    self._settings['paramconv'][paramid] = self._float
                elif convtype.upper() in ('CHAR', 'STRING'):
                    continue
                else:
                    raise KeyError('unknown parameter type %r' % convtype)

    # GCS FUNCTIONS ### DO NOT MODIFY THIS LINE !!! ###############################################

    # CODEGEN BEGIN ### DO NOT MODIFY THIS LINE !!! ###############################################

==> PIPython-2.5.0.1.tar.gz: PIPython-2.5.0.1/pipython/pidevice/gcs2/gcs2commands.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
"""Provide GCS functions to control a PI device."""
# Trailing newlines pylint: disable=C0305

from logging import warning
# Wildcard import pipython.gcscommands_helpers pylint: disable=W0401
# Unused import platform from wildcard import pylint: disable=W0614
from ..common.gcscommands_helpers import *
from ..common.gcsbasecommands import GCSBaseCommands
from .. import gcserror
from ..gcserror import GCSError


__signature__ = 0xf98df39c543ba193811e90bedad17c7

GCSFUNCTIONS = {
    'E-816': [
        'qERR', 'qI2C', 'qIDN', 'StopAll', 'BDR', 'qBDR', 'AVG', 'qAVG', 'SCH', 'qSCH', 'qSAI', 'MAC_BEG', 'MAC_START',
        'MAC_NSTART', 'MAC_DEL', 'MAC_DEF', 'MAC_END', 'MAC_qDEF', 'MAC_qFREE', 'qMAC', 'IsRunningMacro', 'DEL', 'WPA',
        'RST', 'qHLP', 'DCO', 'qDCO', 'MOV', 'MVR', 'qMOV', 'SVA', 'SVR', 'qSVA', 'MVT', 'qMVT', 'qDIP', 'qPOS', 'qVOL',
        'qOVF', 'qONT', 'SVO', 'qSVO', 'SWT', 'qSWT', 'WTO', 'SPA', 'qSPA',
    ],
    'HEXAPOD': [
        'qIDN', 'AAP', 'qCST', 'qECO', 'qERR', 'FAA', 'FAM', 'FAS', 'DMOV', 'DRV', 'FIO', 'FSA', 'FSC', 'FSM', 'FSN',
        'GetPosStatus', 'GetScanResult', 'HasPosChanged', 'INI', 'IsMoving', 'IsRecordingMacro', 'IsScanning',
        'MAC_BEG', 'MAC_DEL', 'MAC_END', 'MAC_qERR', 'MAC_START', 'MOV', 'MWG', 'NAV', 'NLM', 'PLM', 'qCST', 'qDRR',
        'qFSN', 'qHLP', 'qMAC', 'qNAV', 'qNLM', 'qPLM', 'qPOS', 'qSAI', 'qSAI_ALL', 'qSCT', 'qSGA', 'qSPA', 'qSPI',
        'qSSL', 'qSST', 'qSVO', 'qTAV', 'qVEL', 'qVER', 'SCT', 'SGA', 'SPI', 'SSL', 'SST', 'STP', 'SVO', 'TAV', 'VEL',
        'VMO',
    ],
    'TRIPOD': [
        'qIDN', 'AAP', 'qCST', 'qECO', 'qERR', 'FAA', 'FAM', 'FAS', 'DMOV', 'DRV', 'FIO', 'FSA', 'FSC', 'FSM', 'FSN',
        'GetPosStatus', 'GetScanResult', 'HasPosChanged', 'INI', 'IsMoving', 'IsRecordingMacro', 'IsScanning',
        'MAC_BEG', 'MAC_DEL', 'MAC_END', 'MAC_qERR', 'MAC_START', 'MOV', 'MWG', 'NAV', 'NLM', 'PLM', 'qCST', 'qDRR',
        'qFSN', 'qHLP', 'qMAC', 'qNAV', 'qNLM', 'qPLM', 'qPOS', 'qSAI', 'qSAI_ALL', 'qSCT', 'qSGA', 'qSPA', 'qSPI',
        'qSSL', 'qSST', 'qSVO', 'qTAV', 'qVEL', 'qVER', 'SCT', 'SGA', 'SPI', 'SSL', 'SST', 'STP', 'SVO', 'TAV', 'VEL',
        'VMO',
    ],
    'C-702.00': [
        'IsMoving', 'HasPosChanged', 'IsControllerReady', 'IsRunningMacro', 'StopAll', 'SystemAbort', 'q*IDN', 'ACC',
        'qACC', 'CCL', 'qCCL', 'CLR', 'CLS', 'CST', 'qCST', 'qCSV', 'CTO', 'qCTO', 'DEL', 'DFF', 'qDFF', 'DFH', 'qDFH',
        'DIO', 'qDIO', 'DRC', 'qDRC', 'qDRR', 'DRT', 'qDRT', 'DSP', 'qDSP', 'qECO', 'qERR', 'GOH', 'qHDR', 'HID',
        'qHID', 'qHLP', 'HLT', 'IFC', 'qIFC', 'IFS', 'qIFS', 'INI', 'ITD', 'qLIM', 'MAC', 'qMAC', 'MNL', 'MOV', 'qMOV',
        'MPL', 'MSG', 'MVR', 'MVS', 'qMVS', 'NLM', 'qNLM', 'qONT', 'PLM', 'qPLM', 'POS', 'qPOS', 'RBT', 'REF', 'qREF',
        'RON', 'qRON', 'RST', 'RTR', 'qRTR', 'SAI', 'qSAI', 'SAV', 'SCA', 'qSCA', 'SMO', 'qSMO', 'SPA', 'qSPA', 'SSL',
        'qSSL', 'qSSN', 'SSP', 'SST', 'qSST', 'qSTA', 'STP', 'SVO', 'qSVO', 'qTAC', 'qTCV', 'qTIM', 'qTIO', 'qTMN',
        'qTMX', 'qTNR', 'TRO', 'qTRO', 'qTSP', 'qTVI', 'VEL', 'qVEL', 'qVER', 'VMO', 'qVST', 'WAA', 'WAI', 'WAV',
        'qWAV', 'WGO', 'qWGO', 'WPA', 'WSL', 'qWSL',
    ]
}


class GCS2Commands(GCSBaseCommands):
    """Provide functions for GCS commands and communicate with PI controller."""

    def __init__(self, msgs):
        """Wrapper for PI GCS DLL.
        @type msgs : pipython.pidevice.gcsmessages.GCSMessages
        """
        debug('create an instance of GCS2Commands(msgs=%s)', str(msgs))
        super(GCS2Commands, self).__init__(msgs)

    def __str__(self):
        return 'GCS2Commands(msgs=%s)' % str(self._msgs)

    #    @property
    #    def connectionid(self):
    #        """Get ID of current connection as integer."""
    #        return super(GCS2Commands, self).connectionid

    @property
    def devname(self):
        """Return device name from its IDN string."""
        if self._name is None:
            idn = self.qIDN().upper()
            if 'PI-E816' in idn:
                self._name = 'E-816'
            elif 'DIGITAL PIEZO CONTROLLER' in idn:
                self._name = 'E-710'
            else:
                self._name = idn.split(',')[1].strip()
            debug('GCS2Commands.devname: set to %r', self._name)
        return self._name

    @devname.setter
    def devname(self, devname):
        """Set device name as string, only for testing."""
        super(GCS2Commands, self.__class__).devname.fset(self, devname)
        warning('controller name is coerced to %r', self._name)

    @devname.deleter
    def devname(self):
        """Reset device name."""
        self._name = None
        super(GCS2Commands, self.__class__).devname.fdel(self)
        debug('GCS2Commands.devname: reset')

    @property
    def funcs(self):
        """Return list of supported GCS functions."""
        if self._funcs is None:
            if self.devname in GCSFUNCTIONS:
                self._funcs = GCSFUNCTIONS[self.devname]
            else:
                self._funcs = getsupportedfunctions(self.qHLP())
        return self._funcs

    @funcs.deleter
    def funcs(self):
        """Reset list of supported GCS functions."""
        debug('GCS2Commands.funcs: reset')
        super(GCS2Commands, self.__class__).funcs.fdel(self)

    def paramconv(self, paramdict):
        """Convert values in 'paramdict' to according type in qHPA answer.
        @paramdict: Dictionary of {item: {param: value}}.
        @return: Dictionary of {item: {param: value}}.
        """
        self.initparamconv()

        for item in paramdict:
            for param in paramdict[item]:
                if param in self._settings['paramconv']:
                    paramdict[item][param] = self._settings['paramconv'][param](paramdict[item][param])

        return paramdict

    def initparamconv(self):
        """Initialize paramconv .
        """
        if not self._settings['paramconv']:
            for line in self.qHPA().splitlines():
                if '=' not in line:
                    continue
                paramid = int(line.split('=')[0].strip(), base=16)
                convtype = line.split()[3].strip()
                if convtype.upper() == 'INT':
                    self._settings['paramconv'][paramid] = self._int
                elif convtype.upper() == 'FLOAT':
                    self._settings['paramconv'][paramid] = self._float
                elif convtype.upper() in ('CHAR', 'STRING'):
                    continue
                else:
                    raise KeyError('unknown parameter type %r' % convtype)

    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
    def StopAll(self, noraise=False):
        """Stop all axes abruptly by sending "#24".
        Stop all motion caused by move commands (e.g. MOV, MVR, GOH, STE, SVA, SVR), referencing
        commands (e.g. FNL, FPL FRF), macros (e.g. MAC), wave generator output (e.g. WGO) and by
        the autozero procedure (e.g. ATZ) and by the user profile mode (e.g. UP*). Analog input is
        unconnected from the axes. Joystick is disabled.
        May raise GCSError(E10_PI_CNTR_STOP).
        @param noraise : If True a GCS error 10 (controller was stopped by command) will not be raised.
        """
        debug('GCS2Commands.StopAll(noraise=%s)', noraise)
        try:
            self._msgs.send(chr(24))
        except GCSError as exc:
            if noraise and exc == gcserror.E10_PI_CNTR_STOP:
                debug('GCSError 10 is catched and will not raise')
            else:
                raise

    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
    def HasStopAll(self):
        """Return True if StopAll() is available."""
        return self._has('StopAll')

    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
    def IsMoving(self, axes=None):
        """Check if 'axes' are moving.
        If an axis is moving the corresponding element will be True, otherwise False.
        @param axes : String convertible or list of them or None.
        @return : Ordered dictionary of {axis: value}, values are bool.
        """
        debug('GCS2Commands.IsMoving(axes=%r)', axes)
        checksize((), axes)
        answer = self._msgs.read(chr(5))
        value = int(answer.strip(), base=16)
        answerdict = getbitcodeditems(value, self.allaxes, axes)
        debug('GCS2Commands.IsMoving = %r', answerdict)
        return answerdict

    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
    def HasIsMoving(self):
        """Return True if IsMoving() is available."""
        return self._has('IsMoving')

    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
    def IsControllerReady(self):
        """Test if controller is ready, corresponds to GCS command "#7". No error check.
        @return : True if controller is ready.
        """
        debug('GCS2Commands.IsControllerReady()')
        errcheck = self._msgs.errcheck
        self._msgs.errcheck = False
        answer = self._msgs.read(chr(7))
        self._msgs.errcheck = errcheck
        try:
            if ord(answer.strip()) == 177:
                answer = True
            elif ord(answer.strip()) == 176:
                answer = False
            else:
                raise TypeError
        except TypeError:
            raise ValueError('unexpected response %r for IsControllerReady()' % answer)
        debug('GCS2Commands.IsControllerReady = %r', answer)
        return answer

    # Method name "StopAll" doesn't conform to snake_case naming style pylint: disable=C0103
    def HasIsControllerReady(self):
        """Return True if IsControllerReady() is available."""
        return self._has('IsControllerReady')

    # GCS FUNCTIONS ### DO NOT MODIFY THIS LINE !!! ###############################################

    # CODEGEN BEGIN ### DO NOT MODIFY THIS LINE !!! ###############################################
